﻿//
// Copyright (c) 2009-2013, MindFusion LLC - Bulgaria.
//
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using MindFusion.Scheduling;

namespace MindFusion.Scheduling.Samples.CS.CustomAppointment
{
	public class BirthdayAppointment : Appointment
	{
		public BirthdayAppointment()
			: this(DateTime.Today, String.Empty)
		{ }

		public BirthdayAppointment(DateTime birthDate, string birthdayPerson)
			: base()
		{
			this.BirthDate = birthDate;
			this.BirthdayPerson = birthdayPerson;
			this.HeaderText = String.Format("{0}\'s B-day!", birthdayPerson);
			this.Recurrence = CreateBirthdayRecurrence(birthDate);
			this.AllDayEvent = true;
			this.Locked = true;
			CssClass = "CustomAppStyle";
		}

		public DateTime BirthDate { get; private set; }

		public string BirthdayPerson { get; set; }

		private Recurrence CreateBirthdayRecurrence(DateTime birthDate)
		{
			Recurrence rec = new Recurrence();
			rec.StartDate = birthDate.Date;
			rec.Pattern = RecurrencePattern.Yearly;
			rec.YearlyRecurrence = YearlyRecurrence.SpecificDate;
			rec.DayOfMonth = birthDate.Day;
			rec.MonthOfYear = birthDate.Month;
			rec.RecurrenceEnd = RecurrenceEnd.Never;
			return rec;
		}

		public override object SaveViewState()
		{
			ViewState["_birthDate"] = BirthDate;
			ViewState["_birthdayPerson"] = BirthdayPerson;
			return base.SaveViewState();
		}

		public override void LoadViewState(object state)
		{
			base.LoadViewState(state);
			if (ViewState["_birthDate"] != null)
				BirthDate = DateTime.Parse(ViewState["_birthDate"].ToString());
			if (ViewState["_birthdayPerson"] != null)
				BirthdayPerson = ViewState["_birthdayPerson"].ToString();
		}

		protected override void CopyOccurrence(Item master)
		{
			BirthdayAppointment bMaster = master as BirthdayAppointment;
			BirthdayPerson = bMaster.BirthdayPerson;
			BirthDate = bMaster.BirthDate;
			base.CopyOccurrence(master);
		}
	}
}
